SliderFlowTheme class

Constructors

SliderFlowTheme({Color? activeItemColor, Color? inactiveItemColor, double? borderRadius, Color? verticalLineColor, double? verticalLineWidth, TextStyle? labelTextStyle, TextStyle? itemTextStyle})
const

Properties

activeItemColor Color?
final
borderRadius double?
final
hashCode int
The hash code for this object.
no setterinherited
inactiveItemColor Color?
final
itemTextStyle TextStyle?
final
labelTextStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalLineColor Color?
final
verticalLineWidth double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited